
########################### IRENE SALVADOR ORTEGA

# Aplicacin de la seleccin de caractersticas. Tcnica: relief, paquete: FSelector
# Aplicar mtodo relief -> mtodo de filtro (embedded: el criterio lo proporciona otro algoritmo de aprendizaje)
# En este paquete hay que indicar el nmero de vecinos para encontrar cada instancia de muestreo (1) y el nmero de muestras de la instancia (12)

#### Construccin de la tabla que contiene en orden de ms a menos importantes (todas) las caractersticas
#Lectura de la tabla:
library(FSelector)
library(dplyr) #para ordenar los datos

### FUNCIN PRINCIPAL
# Guarda el orden de las caractersticas de cada usuario y los scores de importancia de cada caracterstica en cada usuario
# en formato CSV (cada columna: un usuario)
tabla_caracteristicasImp_FSelector<-function(ruta_inicio_auxiliar, dispositivo, tipo, extension_ventana_EC, solapamiento_EC, experimental, dominio, devolverTabla){
  
  ## 1) Lectura de la tabla sobre la que se van a extraer las caracteristicas
  if(dominio=="DT_X" || dominio=="DT_Y" || dominio=="DT_Z" || dominio=="modulo_DT"){
    preprocesamiento<-"datos_MM3_originales"
  }else if(dominio=="DF_X" || dominio=="DF_Y" || dominio=="DF_Z" || dominio=="modulo_DF"){
    preprocesamiento<-"datos_interpolados"
  }
  
  ruta_inicio<-paste(ruta_inicio_auxiliar,dispositivo,tipo,"/tablas_caract/",preprocesamiento,"/",sep="")
  if(dominio=="DT_X" || dominio=="DT_Y" || dominio=="DT_Z" || dominio=="DF_X" || dominio=="DF_Y" || dominio=="DF_Z"){
    tabla<-read.csv2(paste(ruta_inicio,file=dispositivo,"_",tipo,"_",extension_ventana_EC,"veces_",solapamiento_EC,"%solap_XYZ.csv",sep=""), header=TRUE, sep=";")
  }else if(dominio=="modulo_DT" || dominio=="modulo_DF"){
    tabla<-read.csv2(paste(ruta_inicio,file=dispositivo,"_",tipo,"_",extension_ventana_EC,"veces_",solapamiento_EC,"%solap_modulo.csv",sep=""), header=TRUE, sep=";")
  }
  
  ## 2) Seleccin de las caractersticas en el dominio que se encuentre:
  if(dominio=="DT_X"){
    #cat("Entra en DT_X.\n")
    tabla<-tabla[,names(tabla) %in% c("usuario","sesion","muestra","Periodo_X","Autocorr_X","media_X",
                                      "mediana_X","maximo_X","minimo_X","sd_X","rango_X","kurtosis_X",
                                       "quantil25_X","quantil75_X","skewness_X")]
  }else if(dominio=="DT_Y"){
    #cat("Entra en DT_Y.\n")
    tabla<-tabla[,names(tabla) %in% c("usuario","sesion","muestra","Periodo_Y","Autocorr_Y","media_Y",
                                      "mediana_Y","maximo_Y","minimo_Y","sd_Y","rango_Y","kurtosis_Y",
                                       "quantil25_Y","quantil75_Y","skewness_Y")]
  }else if(dominio=="DT_Z"){
    #cat("Entra en DT_Z.\n")
    tabla<-tabla[,names(tabla) %in% c("usuario","sesion","muestra","Periodo_Z","Autocorr_Z","media_Z",
                                       "mediana_Z","maximo_Z","minimo_Z","sd_Z","rango_Z","kurtosis_Z",
                                       "quantil25_Z","quantil75_Z","skewness_Z")]
  }else if(dominio=="DF_X"){
    #cat("Entra en DF_X.\n")
    tabla<-tabla[,names(tabla) %in% c("usuario","sesion","muestra","Freq_dom1_X","Amp_dom1_X","Freq_dom2_X",
                                      "Amp_dom2_X","AUC_X","media_Ampl_X","mediana_Ampl_X","sd_Ampl_X",
                                       "rango_Ampl_X","kurtosis_Ampl_X","quantil25_Ampl_X","quantil75_Ampl_X",
                                       "skewness_Ampl_X")]
  }else if(dominio=="DF_Y"){
    #cat("Entra en DF_Y.\n")
    tabla<-tabla[,names(tabla) %in% c("usuario","sesion","muestra","Freq_dom1_Y","Amp_dom1_Y","Freq_dom2_Y",
                                       "Amp_dom2_Y","AUC_Y","media_Ampl_Y","mediana_Ampl_Y","sd_Ampl_Y",
                                       "rango_Ampl_Y","kurtosis_Ampl_Y","quantil25_Ampl_Y","quantil75_Ampl_Y",
                                       "skewness_Ampl_Y")]
  }else if(dominio=="DF_Z"){
    #cat("Entra en DF_Z.\n")
    tabla<-tabla[,names(tabla) %in% c("usuario","sesion","muestra","Freq_dom1_Z","Amp_dom1_Z","Freq_dom2_Z",
                                       "Amp_dom2_Z","AUC_Z","media_Ampl_Z","mediana_Ampl_Z","sd_Ampl_Z",
                                       "rango_Ampl_Z","kurtosis_Ampl_Z","quantil25_Ampl_Z","quantil75_Ampl_Z",
                                       "skewness_Ampl_Z")]
  }else if(dominio=="modulo_DT"){
    #cat("Entra en modulo_DT.\n")
    tabla<-tabla[,c(1:15)]
  }else if(dominio=="modulo_DF"){
    #cat("Entra en modulo_DF.\n")
    tabla<-tabla[,c(1:3,16:28)]
  }
  
  tabla_final<-tabla
  tabla_OrdenCaracteristicas<-data.frame(NULL,NULL,NULL)
  tabla_ScoreCaracteristicas<-data.frame(NULL,NULL,NULL)
  columna<-1
  usuario_utilizado<-vector()
  tabla<-"tabla_final"
  for(user in 1:20){
    if(experimental=="MonoMono"){
      test_autenticos<-eval(parse(text = paste(tabla,"[",tabla,"[,\"sesion\"]==\"S1\" & ",tabla, "[,\"muestra\"]==\"M2\" &",tabla, "[,\"usuario\"]==\"usuario", user,"\",]", sep = "")))
      test_impostores<-eval(parse(text = paste(tabla,"[",tabla,"[,\"sesion\"]==\"S1\" & ",tabla, "[,\"muestra\"]==\"M2\" &",tabla, "[,\"usuario\"]!=\"usuario", user,"\",]", sep = "")))
    }else if(experimental=="MultiMono"){
      test_autenticos<-eval(parse(text = paste(tabla,"[",tabla,"[,\"sesion\"]==\"S2\" & ",tabla, "[,\"muestra\"]==\"M1\" &",tabla, "[,\"usuario\"]==\"usuario", user,"\",]", sep = "")))
      test_impostores<-eval(parse(text = paste(tabla,"[",tabla,"[,\"sesion\"]==\"S1\" & ",tabla, "[,\"muestra\"]==\"M2\" &",tabla, "[,\"usuario\"]!=\"usuario", user,"\",]", sep = "")))
    }else if(experimental=="MultiMulti"){
      test_autenticos<-eval(parse(text = paste(tabla,"[",tabla, "[,\"muestra\"]==\"M2\" &",tabla, "[,\"usuario\"]==\"usuario", user,"\",]", sep = "")))
      test_impostores<-eval(parse(text = paste(tabla,"[",tabla, "[,\"muestra\"]==\"M2\" &",tabla, "[,\"usuario\"]!=\"usuario", user,"\",]", sep = "")))
    }
    
    if(dim(test_autenticos)[1]>0 & dim(test_impostores)[1]>0){  #si no, es que no tengo datos suficientes de ese usuario
      test_autenticos$clase<-"autentico"
      test_impostores$clase<-"impostor"
      todo_test<-rbind(test_autenticos, test_impostores)
      todo_test<-todo_test[,!(names(todo_test) %in% c("usuario","sesion","muestra"))]
      
      weights <- relief(clase~., data=todo_test, neighbours.count = 1, sample.size = 12)
      
      weights$nombre<-rownames(weights)
      weights<-arrange(weights, desc(attr_importance))  #esto es lo que quiero guardar como txt
      tabla_OrdenCaracteristicas[1:length(weights$nombre),columna]<-weights$nombre
      tabla_ScoreCaracteristicas[1:length(weights$nombre),columna]<-weights$attr_importance
      columna<-columna+1
      usuario_utilizado<-c(usuario_utilizado, user)
    }
    cat("Fin del usuario ",user,"\n")
  }
  colnames(tabla_OrdenCaracteristicas)<-usuario_utilizado
  colnames(tabla_ScoreCaracteristicas)<-usuario_utilizado
  if(devolverTabla){
    return(tabla_OrdenCaracteristicas)
  }else{
    write.csv2(tabla_OrdenCaracteristicas, file=paste(ruta_inicio_auxiliar,"SeleccionCaracter/", dispositivo,tipo,"/",experimental,"/",dominio,"/ordenCaract_",dominio,"_",extension_ventana_EC,"p",solapamiento_EC,"%solap_RELIEF.csv",sep=""), row.names = FALSE)
    write.csv2(tabla_ScoreCaracteristicas, file=paste(ruta_inicio_auxiliar,"SeleccionCaracter/", dispositivo,tipo,"/",experimental,"/",dominio,"/scoreCaract_",dominio,"_",extension_ventana_EC,"p",solapamiento_EC,"%solap_RELIEF.csv",sep=""), row.names = FALSE)
  }
}



#### Llamada a la funcin principal para cada situacin deseada:
#---> Dominio del tiempo:
tabla_caracteristicasImp_FSelector(ruta_inicio_auxiliar = "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/",
                                  dispositivo = "Micro", tipo = "ACC", extension_ventana_EC = 8, solapamiento_EC = 20, experimental = "MonoMono", dominio="DT_X", devolverTabla = FALSE)
tabla_caracteristicasImp_FSelector(ruta_inicio_auxiliar = "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/",
                                   dispositivo = "Micro", tipo = "ACC", extension_ventana_EC = 8, solapamiento_EC = 20, experimental = "MonoMono", dominio="DT_Y", devolverTabla = FALSE)
tabla_caracteristicasImp_FSelector(ruta_inicio_auxiliar = "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/",
                                   dispositivo = "Micro", tipo = "ACC", extension_ventana_EC = 8, solapamiento_EC = 20, experimental = "MonoMono", dominio="DT_Z", devolverTabla = FALSE)
tabla_caracteristicasImp_FSelector(ruta_inicio_auxiliar = "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/",
                                   dispositivo = "Micro", tipo = "ACC", extension_ventana_EC = 8, solapamiento_EC = 20, experimental = "MonoMono", dominio="modulo_DT", devolverTabla = FALSE)

#---> Dominio de la frecuencia:
tabla_caracteristicasImp_FSelector(ruta_inicio_auxiliar = "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/",
                                   dispositivo = "Micro", tipo = "ACC", extension_ventana_EC = 8, solapamiento_EC = 20, experimental = "MonoMono", dominio="DF_X", devolverTabla = FALSE)
tabla_caracteristicasImp_FSelector(ruta_inicio_auxiliar = "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/",
                                   dispositivo = "Micro", tipo = "ACC", extension_ventana_EC = 8, solapamiento_EC = 20, experimental = "MonoMono", dominio="DF_Y", devolverTabla = FALSE)
tabla_caracteristicasImp_FSelector(ruta_inicio_auxiliar = "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/",
                                   dispositivo = "Micro", tipo = "ACC", extension_ventana_EC = 8, solapamiento_EC = 20, experimental = "MonoMono", dominio="DF_Z", devolverTabla = FALSE)
tabla_caracteristicasImp_FSelector(ruta_inicio_auxiliar = "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/",
                                   dispositivo = "Micro", tipo = "ACC", extension_ventana_EC = 8, solapamiento_EC = 20, experimental = "MonoMono", dominio="modulo_DF", devolverTabla = FALSE)


### Selecciona las caractersticas que superan un determinado valor umbral dado como entrada.
# Para el dominio concreto, lectura de los ordenes y de las puntuaciones de las caractersticas en los distintos usuarios
ruta_inicio_auxiliar <- "C:/Users/Irene Salvador/Desktop/QUINTO CURSO/---------- TFG/RendimientoFinal_seq/"
dispositivo <- "Micro"
tipo <- "ACC"
experimental <- "MonoMono"
extension_ventana_EC <- 8
solapamiento_EC <- 20

guardarScoresOrdenUmbral<-function(ordenes, scores, umbral, u){
  atributos_finales<-unique(ordenes[scores>umbral])
  scores_finales<-vector()
  for(i in 1:length(unique(ordenes[scores>umbral]))){
    atributo<-unique(ordenes[scores>umbral])[i]
    scores_finales<-c(scores_finales, max(scores[scores>umbral][ordenes[scores>umbral]==atributo]))
  }
  
  #guardar en orden
  tabla_auxiliar<-as.data.frame(cbind(atributos_finales, scores_finales))
  tabla_auxiliar<-arrange(tabla_auxiliar, desc(scores_finales))
  atributos_finales<-as.character(tabla_auxiliar$atributos_finales)
  scores_finales<-as.numeric(as.character(tabla_auxiliar$scores_finales))
  write.table(atributos_finales, file=paste(ruta_inicio_auxiliar,"SeleccionCaracter/", dispositivo,tipo,"/",experimental,"/",dominio,"/umbralVariable/ordenCaract_",dominio,"_umbral_",u,"_RELIEF.txt",sep=""), row.names = FALSE, col.names = FALSE, sep=",")
  write.table(scores_finales, file=paste(ruta_inicio_auxiliar,"SeleccionCaracter/", dispositivo,tipo,"/",experimental,"/",dominio,"/umbralVariable/scoresCaract_",dominio,"_umbral_",u,"_",round(umbral,4),"_RELIEF.txt",sep=""), row.names = FALSE, col.names = FALSE, sep=",")
}


dominio<-"modulo_DF"
ordenes<-read.csv2(file=paste(ruta_inicio_auxiliar,"SeleccionCaracter/", dispositivo,tipo,"/",experimental,"/",dominio,"/ordenCaract_",dominio,"_",extension_ventana_EC,"p",solapamiento_EC,"%solap_RELIEF.csv",sep=""), header=TRUE)
scores<-read.csv2(file=paste(ruta_inicio_auxiliar,"SeleccionCaracter/", dispositivo,tipo,"/",experimental,"/",dominio,"/scoreCaract_",dominio,"_",extension_ventana_EC,"p",solapamiento_EC,"%solap_RELIEF.csv",sep=""), header=TRUE)
max(scores)

guardarScoresOrdenUmbral(ordenes=ordenes, scores=scores, umbral=(2/4)*max(scores), u="2_4")
guardarScoresOrdenUmbral(ordenes=ordenes, scores=scores, umbral=(2/3)*max(scores), u="2_3")
guardarScoresOrdenUmbral(ordenes=ordenes, scores=scores, umbral=(3/4)*max(scores), u="3_4")



